==> igniteui-angular-charts-14.1.1.tgz: package/esm2015/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PolarAreaSeries = /*@__PURE__*/ (() => {
    class PolarAreaSeries extends PolarLineSeriesBase {
        constructor() {
            super();
            this.ab = PolarAreaSeries.$;
        }
        get_dd() {
            return true;
        }
        bx() {
            return new PolarAreaSeriesView(this);
        }
        lz(a) {
            super.lz(a);
            this.vg = a;
        }
        ve(a) {
            let b = a;
            b.c5();
        }
        vf(a, b) {
            if (a.m.count > 0) {
                let c = a.m._inner[0];
                let d = a.m._inner[a.m.count - 1];
                let e = c.x == d.x && c.y == d.y;
                if (!e) {
                    a.m.add(a.m._inner[0]);
                }
            }
            let f = b;
            f.c6(a.m, this.ft);
            this.r6.ax(this, this.st(), runOn(this, this.rj));
            let g = false;
            let h = this.r6.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                this.t1(-1, this.sf.count, b.q);
            }
            let i = f.dc;
            let j = f.db;
            this.r6.ad(i, true, false, true, true);
            this.r6.ad(j, false, true, false, false);
            j._opacity = this.r6.j * this.fq;
        }
        get_vb() {
            return true;
        }
        u6() {
            return this.vh;
        }
    }
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vh:vj', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
})();
/**
 * @hidden
 */
export let PolarAreaSeriesView = /*@__PURE__*/ (() => {
    class PolarAreaSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c4 = null;
            this.da = new Path();
            this.c9 = new Path();
            this.c8 = new Path();
            this.c7 = new Path();
            this.c4 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.c4.qd = Defaults.e;
            }
        }
        get db() {
            return this.c9;
        }
        get dc() {
            return this.da;
        }
        c5() {
            this.c9.ak = null;
            this.da.ak = null;
            this.c7.ak = null;
            this.c8.ak = null;
            this.aq();
        }
        c6(a, b) {
            let c = new List$1(Point_$type, 1, a);
            this.c4.u3.d(this.da, c, b);
            this.c4.u3.d(this.c9, c, b);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c8.ak = this.da.ak;
            this.c7.ak = this.c9.ak;
            this.c8._stroke = a;
            this.c8.ac = this.e.fu + 3;
            this.c7._fill = a;
            this.c7._opacity = 1;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c7);
                    a.s(this.c8);
                }
                else {
                    a.s(this.c9);
                    a.s(this.da);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.da, "polarShape", ["Main"]);
            this.e.a8.exportPathData(a, this.c9, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pb = a;
            this.e.gw = 5;
            this.e.gx = 5;
            this.e.gy = 5;
        }
    }
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
})();

==> igniteui-angular-charts-14.2.0.tgz: package/esm2015/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PolarAreaSeries = /*@__PURE__*/ (() => {
    class PolarAreaSeries extends PolarLineSeriesBase {
        constructor() {
            super();
            this.ab = PolarAreaSeries.$;
        }
        get_dd() {
            return true;
        }
        bx() {
            return new PolarAreaSeriesView(this);
        }
        l2(a) {
            super.l2(a);
            this.vk = a;
        }
        vi(a) {
            let b = a;
            b.c5();
        }
        vj(a, b) {
            if (a.m.count > 0) {
                let c = a.m._inner[0];
                let d = a.m._inner[a.m.count - 1];
                let e = c.x == d.x && c.y == d.y;
                if (!e) {
                    a.m.add(a.m._inner[0]);
                }
            }
            let f = b;
            f.c6(a.m, this.fv);
            this.sa.ax(this, this.sx(), runOn(this, this.rn));
            let g = false;
            let h = this.sa.b;
            if (h != null) {
                g = true;
            }
            if (g) {
                this.t5(-1, this.sj.count, b.q);
            }
            let i = f.dc;
            let j = f.db;
            this.sa.ad(i, true, false, true, true);
            this.sa.ad(j, false, true, false, false);
            j._opacity = this.sa.j * this.fs;
        }
        get_vf() {
            return true;
        }
        va() {
            return this.vl;
        }
    }
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vl:vn', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
})();
/**
 * @hidden
 */
export let PolarAreaSeriesView = /*@__PURE__*/ (() => {
    class PolarAreaSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c4 = null;
            this.da = new Path();
            this.c9 = new Path();
            this.c8 = new Path();
            this.c7 = new Path();
            this.c4 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.c4.qh = Defaults.e;
            }
        }
        get db() {
            return this.c9;
        }
        get dc() {
            return this.da;
        }
        c5() {
            this.c9.ak = null;
            this.da.ak = null;
            this.c7.ak = null;
            this.c8.ak = null;
            this.aq();
        }
        c6(a, b) {
            let c = new List$1(Point_$type, 1, a);
            this.c4.u7.d(this.da, c, b);
            this.c4.u7.d(this.c9, c, b);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c8.ak = this.da.ak;
            this.c7.ak = this.c9.ak;
            this.c8._stroke = a;
            this.c8.ac = this.e.fw + 3;
            this.c7._fill = a;
            this.c7._opacity = 1;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c7);
                    a.s(this.c8);
                }
                else {
                    a.s(this.c9);
                    a.s(this.da);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.da, "polarShape", ["Main"]);
            this.e.a8.exportPathData(a, this.c9, "fillShape", ["Fill"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.pf = a;
            this.e.gy = 5;
            this.e.gz = 5;
            this.e.g0 = 5;
        }
    }
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
})();
